# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "acl_host": "aclHost",
    "acl_operation": "aclOperation",
    "acl_permission_type": "aclPermissionType",
    "acl_principal": "aclPrincipal",
    "acl_resource_name": "aclResourceName",
    "acl_resource_type": "aclResourceType",
    "replication_factor": "replicationFactor",
    "resource_pattern_type_filter": "resourcePatternTypeFilter",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "aclHost": "acl_host",
    "aclOperation": "acl_operation",
    "aclPermissionType": "acl_permission_type",
    "aclPrincipal": "acl_principal",
    "aclResourceName": "acl_resource_name",
    "aclResourceType": "acl_resource_type",
    "replicationFactor": "replication_factor",
    "resourcePatternTypeFilter": "resource_pattern_type_filter",
}
